@@ -1,6 +1,6 @@
 use crate::serde_utils::ValueDeserializer;
 use crate::utils;
-use ansi_term::Color;
+use nu_ansi_term::Color;
 use serde::{
     de::value::Error as ValueError, de::Error as SerdeError, Deserialize, Deserializer, Serialize,
 };
@@ -251,7 +251,7 @@ impl StarshipConfig {
 }
 
 /// Deserialize a style string in the starship format with serde
-pub fn deserialize_style<'de, D>(de: D) -> Result<ansi_term::Style, D::Error>
+pub fn deserialize_style<'de, D>(de: D) -> Result<nu_ansi_term::Style, D::Error>
 where
     D: Deserializer<'de>,
 {
@@ -271,10 +271,10 @@ where
  - 'blink'
  - '<color>'       (see the `parse_color_string` doc for valid color strings)
 */
-pub fn parse_style_string(style_string: &str) -> Option<ansi_term::Style> {
+pub fn parse_style_string(style_string: &str) -> Option<nu_ansi_term::Style> {
     style_string
         .split_whitespace()
-        .fold(Some(ansi_term::Style::new()), |maybe_style, token| {
+        .fold(Some(nu_ansi_term::Style::new()), |maybe_style, token| {
             maybe_style.and_then(|style| {
                 let token = token.to_lowercase();
 
@@ -333,7 +333,7 @@ pub fn parse_style_string(style_string: &str) -> Option<ansi_term::Style> {
   - u8           (a number from 0-255, representing an ANSI color)
   - colstring    (one of the 16 predefined color strings)
 */
-fn parse_color_string(color_string: &str) -> Option<ansi_term::Color> {
+fn parse_color_string(color_string: &str) -> Option<nu_ansi_term::Color> {
     // Parse RGB hex values
     log::trace!("Parsing color_string: {}", color_string);
     if color_string.starts_with('#') {
@@ -349,7 +349,7 @@ fn parse_color_string(color_string: &str) -> Option<ansi_term::Color> {
         let g: u8 = u8::from_str_radix(&color_string[3..5], 16).ok()?;
         let b: u8 = u8::from_str_radix(&color_string[5..7], 16).ok()?;
         log::trace!("Read RGB color string: {},{},{}", r, g, b);
-        return Some(Color::RGB(r, g, b));
+        return Some(Color::Rgb(r, g, b));
     }
 
     // Parse a u8 (ansi color)
@@ -369,14 +369,14 @@ fn parse_color_string(color_string: &str) -> Option<ansi_term::Color> {
         "purple" => Some(Color::Purple),
         "cyan" => Some(Color::Cyan),
         "white" => Some(Color::White),
-        "bright-black" => Some(Color::Fixed(8)), // "bright-black" is dark grey
-        "bright-red" => Some(Color::Fixed(9)),
-        "bright-green" => Some(Color::Fixed(10)),
-        "bright-yellow" => Some(Color::Fixed(11)),
-        "bright-blue" => Some(Color::Fixed(12)),
-        "bright-purple" => Some(Color::Fixed(13)),
-        "bright-cyan" => Some(Color::Fixed(14)),
-        "bright-white" => Some(Color::Fixed(15)),
+        "bright-black" => Some(Color::DarkGray), // "bright-black" is dark grey
+        "bright-red" => Some(Color::LightRed),
+        "bright-green" => Some(Color::LightGreen),
+        "bright-yellow" => Some(Color::LightYellow),
+        "bright-blue" => Some(Color::LightBlue),
+        "bright-purple" => Some(Color::LightPurple),
+        "bright-cyan" => Some(Color::LightCyan),
+        "bright-white" => Some(Color::LightGray),
         _ => None,
     };
 
@@ -391,7 +391,7 @@ fn parse_color_string(color_string: &str) -> Option<ansi_term::Color> {
 #[cfg(test)]
 mod tests {
     use super::*;
-    use ansi_term::Style;
+    use nu_ansi_term::Style;
 
     // Small wrapper to allow deserializing Style without a struct with #[serde(deserialize_with=)]
     #[derive(Default, Clone, Debug, PartialEq)]
@@ -574,7 +574,7 @@ mod tests {
         let config = Value::from("#a12BcD");
         assert_eq!(
             <StyleWrapper>::from_config(&config).unwrap().0,
-            Color::RGB(0xA1, 0x2B, 0xCD).into()
+            Color::Rgb(0xA1, 0x2B, 0xCD).into()
         );
     }
 
@@ -600,7 +600,7 @@ mod tests {
         assert!(mystyle.is_dimmed);
         assert_eq!(
             mystyle,
-            ansi_term::Style::new()
+            nu_ansi_term::Style::new()
                 .bold()
                 .italic()
                 .underline()
@@ -620,7 +620,7 @@ mod tests {
         assert!(mystyle.is_reverse);
         assert_eq!(
             mystyle,
-            ansi_term::Style::new()
+            nu_ansi_term::Style::new()
                 .bold()
                 .italic()
                 .underline()
@@ -641,7 +641,7 @@ mod tests {
         assert!(mystyle.is_blink);
         assert_eq!(
             mystyle,
-            ansi_term::Style::new()
+            nu_ansi_term::Style::new()
                 .bold()
                 .italic()
                 .underline()
@@ -662,7 +662,7 @@ mod tests {
         assert!(mystyle.is_hidden);
         assert_eq!(
             mystyle,
-            ansi_term::Style::new()
+            nu_ansi_term::Style::new()
                 .bold()
                 .italic()
                 .underline()
@@ -683,7 +683,7 @@ mod tests {
         assert!(mystyle.is_strikethrough);
         assert_eq!(
             mystyle,
-            ansi_term::Style::new()
+            nu_ansi_term::Style::new()
                 .bold()
                 .italic()
                 .underline()
@@ -698,7 +698,7 @@ mod tests {
         // Test a "plain" style with no formatting
         let config = Value::from("");
         let plain_style = <StyleWrapper>::from_config(&config).unwrap().0;
-        assert_eq!(plain_style, ansi_term::Style::new());
+        assert_eq!(plain_style, nu_ansi_term::Style::new());
 
         // Test a string that's clearly broken
         let config = Value::from("djklgfhjkldhlhk;j");
@@ -763,7 +763,7 @@ mod tests {
             Style::new()
                 .underline()
                 .fg(Color::Fixed(120))
-                .on(Color::RGB(5, 5, 5))
+                .on(Color::Rgb(5, 5, 5))
         );
 
         // Test that the last color style is always the one used
