@@ -11,6 +11,9 @@ pub struct KubernetesConfig<'a> {
     pub disabled: bool,
     pub context_aliases: HashMap<String, &'a str>,
     pub user_aliases: HashMap<String, &'a str>,
+    pub detect_extensions: Vec<&'a str>,
+    pub detect_files: Vec<&'a str>,
+    pub detect_folders: Vec<&'a str>,
 }
 
 impl<'a> Default for KubernetesConfig<'a> {
@@ -22,6 +25,9 @@ impl<'a> Default for KubernetesConfig<'a> {
             disabled: true,
             context_aliases: HashMap::new(),
             user_aliases: HashMap::new(),
+            detect_extensions: vec![],
+            detect_files: vec![],
+            detect_folders: vec![],
         }
     }
 }
