@@ -5,6 +5,7 @@ pub mod aws;
 pub mod azure;
 pub mod battery;
 pub mod buf;
+pub mod bun;
 pub mod c;
 pub mod character;
 pub mod cmake;
@@ -100,6 +101,8 @@ pub struct FullConfig<'a> {
     #[serde(borrow)]
     buf: buf::BufConfig<'a>,
     #[serde(borrow)]
+    bun: bun::BunConfig<'a>,
+    #[serde(borrow)]
     c: c::CConfig<'a>,
     #[serde(borrow)]
     character: character::CharacterConfig<'a>,
