@@ -268,7 +268,7 @@ mod tests {
     use super::*;
 
     use crate::test::ModuleRenderer;
-    use ansi_term::Color;
+    use nu_ansi_term::Color;
     use std::fs::File;
     use std::io;
 
