@@ -129,6 +129,10 @@ pub fn mock_cmd<T: AsRef<OsStr> + Debug, U: AsRef<OsStr> + Debug>(
 ) -> Option<Option<CommandOutput>> {
     let command = display_command(&cmd, args);
     let out = match command.as_str() {
+        "bun --version"=> Some(CommandOutput {
+            stdout: String::from("0.1.4\n"),
+            stderr: String::default(),
+        }),
         "buf --version" => Some(CommandOutput {
             stdout: String::from("1.0.0"),
             stderr: String::default(),
